@@ -196,6 +196,7 @@ eel_enumeration_new_from_tokens (const char *id,
 	EelStringList *name_list;
 	EelStringList *description_list;
 	EelStringList *value_list;
+	int length;
 	guint i;
 	int value;
 
@@ -213,8 +214,8 @@ eel_enumeration_new_from_tokens (const char *id,
 	name_list = eel_string_list_new_from_tokens (names, delimiter, TRUE);
 	value_list = eel_string_list_new_from_tokens (values, delimiter, TRUE);
 
-	if (eel_string_list_get_length (name_list)
-	    != eel_string_list_get_length (value_list)) {
+	length = eel_string_list_get_length (name_list);
+	if (eel_string_list_get_length (value_list) != length) {
 		g_warning ("names and values have different lengths.");
 		eel_string_list_free (name_list);
 		eel_string_list_free (value_list);
@@ -227,8 +228,7 @@ eel_enumeration_new_from_tokens (const char *id,
 		NULL;
 
 	if (description_list != NULL) {
-		if (eel_string_list_get_length (name_list)
-		    != eel_string_list_get_length (description_list)) {
+		if (eel_string_list_get_length (description_list) != length) {
 			g_warning ("names and descriptions have different lengths.");
 			eel_string_list_free (name_list);
 			eel_string_list_free (value_list);
@@ -242,22 +242,23 @@ eel_enumeration_new_from_tokens (const char *id,
 	if (description_list == NULL) {
 		description_list = eel_string_list_new (TRUE);
 
-		for (i = 0; i < eel_string_list_get_length (name_list); i++) {
+		for (i = 0; i < length; i++) {
 			eel_string_list_insert (description_list, "");
 		}
 	}
-	
+
 	enumeration->names = name_list;
 	enumeration->descriptions = description_list;
 
-	for (i = 0; i < eel_string_list_get_length (name_list); i++) {
+	for (i = 0; i < length; i++) {
 		if (!eel_string_list_nth_as_integer (value_list, i, &value)) {
 			g_warning ("Could not convert value '%d' to an integer.  Using 0.", i);
 			value = 0;
 		}
 
-		enumeration->values = g_list_append (enumeration->values, GINT_TO_POINTER (value));
+		enumeration->values = g_list_prepend (enumeration->values, GINT_TO_POINTER (value));
 	}
+	enumeration->values = g_list_reverse (enumeration->values);
 	eel_string_list_free (value_list);
 	
 	return enumeration;
