@@ -2247,7 +2247,7 @@ eel_labeled_image_get_accessible (GtkWidget *widget)
 	}
 
 	if (!types [i]) {
-		static const GInterfaceInfo atk_image_info = {
+		const GInterfaceInfo atk_image_info = {
 			(GInterfaceInitFunc) eel_labeled_image_accessible_image_interface_init,
 			(GInterfaceFinalizeFunc) NULL,
 			NULL
