@@ -576,7 +576,7 @@ eel_mime_application_chooser_get_type (void)
 	static GType type = 0;
 	
 	if (!type) {
-		static const GTypeInfo info = {
+		const GTypeInfo info = {
 			sizeof (EelMimeApplicationChooserClass),
 			NULL, 
 			NULL,
