@@ -533,6 +533,7 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 {
 	GSList *contents;
 	GSList *l;
+	const char *exec;
 
 	contents = gmenu_tree_directory_get_contents (directory);
 
@@ -546,7 +547,14 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 				break;
 
 			case GMENU_TREE_ITEM_ENTRY:
-				list = g_slist_prepend (list, item);
+				exec = gmenu_tree_entry_get_exec ((GMenuTreeEntry*)item);
+				/* Only add items that actually accept a file */
+				if (strstr (exec,"%U") != NULL ||
+				    strstr (exec,"%u") != NULL ||
+				    strstr(exec,"%f") != NULL ||
+				    strstr(exec,"%F") != NULL) {
+					list = g_slist_prepend (list, item);
+				}
 				break;
 
 			default:
@@ -957,6 +965,7 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 {
 	char *label;
 	char *name;
+	char *emname;
 	GnomeVFSURI *vfs_uri;
 
 	dialog->details->uri = g_strdup (uri);
@@ -999,7 +1008,7 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 		dialog->details->mime_description = description;
 	}
 
-	gchar *emname = g_strdup_printf ("<i>%s</i>", name);
+	emname = g_strdup_printf ("<i>%s</i>", name);
 	label = g_strdup_printf (_("Open %s and other files of type \"%s\" with:"), emname, dialog->details->mime_description);
 	g_free (emname);
 
@@ -1044,7 +1053,7 @@ eel_open_with_dialog_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		static const GTypeInfo info = {
+		const GTypeInfo info = {
 			sizeof (EelOpenWithDialogClass),
 			NULL,
 			NULL,
